pub enum BodyArg {
Scalar(SizedValue),
Aggregate(Vec<SizedValue>),
}Expand description
A positional argument to a map body for run_map_body:
a scalar param value, or the field vector of an aggregate (tuple) param.
Variants
Scalar(SizedValue)
Aggregate(Vec<SizedValue>)